@@ -82,8 +82,11 @@ def singleton(class_):
 
 
 class Worker:
-    def __init__(self, worker_name, create_if_not_exist=True, segment_limit=200):
-        self.connection_string = os.environ['AzureWebJobsStorage']
+    def __init__(self, worker_name, create_if_not_exist=True, segment_limit=200, connection_string=None):
+        if connection_string is None:
+            self.connection_string = os.environ['AzureWebJobsStorage']
+        else:
+            self.connection_string = connection_string
         self.metadata_table_name = worker_name + "Data"
         self.queue_name = worker_name.lower()
         self.worker_name = worker_name
@@ -164,9 +167,9 @@ class Worker:
         return entity
 
     def process_message(self, request_id, func):
+        guid, request_hash = self._decode_id(request_id)
+        request_entity = self.table_client.get_entity(self.metadata_table_name, guid, request_hash)
         try:
-            guid, request_hash = self._decode_id(request_id)
-            request_entity = self.table_client.get_entity(self.metadata_table_name, guid, request_hash)
             if 'Request' in request_entity:
                 self._process_request_body(request_entity, func)
             if 'BlobName' in request_entity:
